namespace UpdateVersion
{
	/// <summary>
	/// Specifies the algorithm to use when calculating a new build number.
	/// </summary>
	internal enum BuildNumberType
	{
		/// <summary>
		/// Indicates the build number should not change.
		/// </summary>
		Fixed,

		/// <summary>
		/// Indicates the build number should be calculated using the number of months 
		/// since the start of the project as the plus the current day, in the 
		/// current month, as the build number.
		/// </summary>
		MonthDay,

		/// <summary>
		/// Indicates the build number should be calculated by incrementing the existing 
		/// build number by one.
		/// </summary>
		Increment,

		/// <summary>
		/// Creates a build number that is the last digit of the current year
		/// concatenated with the day of the year.
		/// </summary>
		BuildDay,

		/// <summary>
		/// Indicates a custom date/time format.
		/// </summary>
		DateTimeFormat
	}
}